<?php
/**
 * Plugin Name: Fast News Ticker
 * Description: This plugin will allow you to place scrolling text.
 * Version: 1.1.1
 * Author: Eniverse
 * Author URI: https://eniverse.pl
 * Text Domain: fast-news-ticker
 * Domain Path: /languages/
 * Requires PHP: 7.2
 * License: GPL v3
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

defined( 'ABSPATH' ) || exit;

class FastNewsTicker {

	public $options;

	public function __construct() {
		load_plugin_textdomain('fast-news-ticker', false, dirname(plugin_basename(__FILE__)) . '/languages');

		add_action('admin_menu', [$this, 'fnt_add_page']);
		add_action('admin_init', [$this, 'fnt_api_settings_init']);
		add_action('wp_enqueue_scripts', [$this, 'fnt_add_footer']);

		wp_enqueue_style('wp-color-picker');
		add_action('admin_enqueue_scripts', [$this, 'fnt_add_admin_js'] );

		$this->options = get_option('fnt_api_settings');
	}

	public function fnt_add_page() {
		add_menu_page(
			__('Content text color', 'fast-news-ticker'),
			__('News Ticker', 'fast-news-ticker'),
			'manage_options',
			'fast-news-ticker',
			[$this, 'fnt_option_page'],
			'dashicons-admin-site-alt3',
			30
		);
	}

	public function fnt_api_settings_init() {
		register_setting(
			'fnt_plugin',
			'fnt_api_settings'
		);
		
		add_settings_section(
			'fnt_settings_section',
			esc_attr__('Settings', 'fast-news-ticker'),
			[$this, 'fnt_api_settings_section_callback'],
			'fnt_plugin'
		);
		
		add_settings_field(
			'fnt_text_field_name',
			esc_attr__('Title', 'fast-news-ticker'),
			[$this, 'fnt_text_field_name_render'],
			'fnt_plugin',
			'fnt_settings_section'
		);

		add_settings_field(
			'fnt_text_field_content',
			esc_attr__('Content', 'fast-news-ticker'),
			[$this, 'fnt_text_field_content_render'],
			'fnt_plugin',
			'fnt_settings_section'
		);

		add_settings_field(
			'fnt_bg_color_field_name',
			esc_attr__('Title background color', 'fast-news-ticker'),
			[$this, 'fnt_bg_color_field_name_render'],
			'fnt_plugin',
			'fnt_settings_section'
		);

		add_settings_field(
			'fnt_color_field_name',
			esc_attr__('Title text color', 'fast-news-ticker'),
			[$this, 'fnt_color_field_name_render'],
			'fnt_plugin',
			'fnt_settings_section'
		);

		add_settings_field(
			'fnt_bg_color_field_content',
			esc_attr__('Content background color', 'fast-news-ticker'),
			[$this, 'fnt_bg_color_field_content_render'],
			'fnt_plugin',
			'fnt_settings_section'
		);

		add_settings_field(
			'fnt_color_field_content',
			esc_attr__('Content text color', 'fast-news-ticker'),
			[$this, 'fnt_color_field_content_render'],
			'fnt_plugin',
			'fnt_settings_section'
		);

	}

	public function fnt_api_settings_section_callback() {
		echo '<p>' . esc_html__('Complete the data below.', 'fast-news-ticker') . '</p>';
	}

	public function fnt_text_field_name_render() {
		echo '<input type="text" id="fnt_text_field_name" name="fnt_api_settings[fnt_text_field_name]" value="' . esc_attr($this->options['fnt_text_field_name']) . '" class="regular-text">';
	}

	public function fnt_text_field_content_render() {
		$settings = [
			'media_buttons' => false, 
			'tinymce' => [
				'toolbar1' => 'bold,italic,underline,separator,forecolor,separator,link,unlink,removeformat,undo,redo',
				'toolbar2' => '',
				'toolbar3' => '',
			],
			'textarea_name' => 'fnt_api_settings[fnt_text_field_content]',
			'textarea_rows' => 10,
			'quicktags' => false
		];
		wp_editor($this->options['fnt_text_field_content'], 'fnt_text_field_content', $settings);
		echo '<p class="description">' . esc_html__('Enter the content of your scroll bar here.', 'fast-news-ticker') . '</p>';
	}

	public function fnt_bg_color_field_name_render() {
		echo '<input type="text" id="fnt_bg_color_field_name" name="fnt_api_settings[fnt_bg_color_field_name]" value="' . esc_attr($this->options['fnt_bg_color_field_name']) . '" class="fnt-color-picker">';
	}

	public function fnt_color_field_name_render() {
		echo '<input type="text" id="fnt_color_field_name" name="fnt_api_settings[fnt_color_field_name]" value="' . esc_attr($this->options['fnt_color_field_name']) . '" class="fnt-color-picker">';
	}

	public function fnt_bg_color_field_content_render() {
		echo '<input type="text" id="fnt_bg_color_field_content" name="fnt_api_settings[fnt_bg_color_field_content]" value="' . esc_attr($this->options['fnt_bg_color_field_content']) . '" class="fnt-color-picker">';
	}

	public function fnt_color_field_content_render() {
		echo '<input type="text" id="fnt_color_field_content" name="fnt_api_settings[fnt_color_field_content]" value="' . esc_attr($this->options['fnt_color_field_content']) . '" class="fnt-color-picker">';
	}
	
	public function fnt_option_page() {
		?>
		<div class="wrap">
			<h2><?php esc_html__('News Ticker', 'fast-news-ticker'); ?></h2>

			<?php if( isset($_POST['submit']) ): ?>
				<div class="updated"><p><strong><?php esc_html__('The settings have been saved.', 'fast-news-ticker'); ?></strong></p></div>
			<?php endif; ?>

			<form action="options.php" method="POST">
				<?php
				settings_fields('fnt_plugin');
        		do_settings_sections('fnt_plugin');
				submit_button();
				?>
			</form>
		</div>
		<?php
	}

	public function fnt_add_admin_js() {
		wp_enqueue_script('fast-news-ticker-admin', plugins_url('/assets/js/color-picker.js', __FILE__ ), ['jquery', 'wp-color-picker'], '0.1', true);	
	}

	public function fnt_add_footer() {
		// CSS
		wp_enqueue_style('fast-news-ticker', plugins_url('/assets/css/fastnewsticker.css' , __FILE__ ), [], '0.3');
		// Inline CSS
		wp_add_inline_style('fast-news-ticker', '.breaking-news .title h4{background-color:'. esc_html($this->options['fnt_bg_color_field_name']) .';color:'. esc_html($this->options['fnt_color_field_name']) .'}.breaking-news .content{background-color:'. esc_html($this->options['fnt_bg_color_field_content']) .';color:'. esc_html($this->options['fnt_color_field_content']) .'}');

		// JavaScript 
		wp_enqueue_script('jquery-marquee', plugins_url('/assets/js/jquery.marquee.min.js' , __FILE__ ), ['jquery'], '1.3.1', true);
		wp_enqueue_script('fast-news-ticker', plugins_url('/assets/js/fastnewsticker.js' , __FILE__ ), ['jquery-marquee'], '0.3', true);
	}

	public static function show() {
		$options = get_option('fnt_api_settings');

		$output = '';

		$output .= '<div class="breaking-news">';
		if(!empty($options)) {
			$output .= '<div class="title"><h4>' . esc_html($options['fnt_text_field_name']) . '</h4></div>';
			$output .= '<div class="content">' . $options['fnt_text_field_content'] . '</div>';
		}
		$output .= '</div>';
		return $output;
	}

}

new FastNewsTicker();